@@ -17,11 +17,14 @@
  *************************************************************************************/
 
 #include "createavatarjob.h"
+#include "user_manager_debug.h"
 
 #include <QImage>
-#include "user_manager_debug.h"
-#include <kio/copyjob.h>
-#include <KTemporaryFile>
+#include <QPixmap>
+#include <QTemporaryFile>
+#include <QtGlobal>
+
+#include <KIO/CopyJob>
 #include <KPixmapRegionSelectorDialog>
 
 CreateAvatarJob::CreateAvatarJob(QObject* parent) : KJob(parent)
@@ -47,7 +50,7 @@ void CreateAvatarJob::doStart()
 {
     qCDebug(USER_MANAGER_LOG) << "Starting: " << m_url;
 
-    KTemporaryFile file;
+    QTemporaryFile file;
     file.open();
     m_tmpFile = file.fileName();
     file.remove();
@@ -68,8 +71,25 @@ void CreateAvatarJob::copyDone(KJob* job)
         return;
     }
 
-#warning KPixmapRegionSelectorDialog is no longer available
-    QImage face; // = KPixmapRegionSelectorDialog::getSelectedImage(QPixmap(m_tmpFile), 192, 192);
-    face.save(m_tmpFile, "PNG", 10);
+    QImage face = KPixmapRegionSelectorDialog::getSelectedImage(QPixmap(m_tmpFile), 192, 192);
+    if (face.isNull()) {
+        qCDebug(USER_MANAGER_LOG) << "Icon region selection aborted";
+        setError(UserDefinedError);
+        emitResult();
+        return;
+    }
+
+    /* Accountmanager doesn't allow icon which are bigger than 1MB */
+    face = face.scaledToWidth(qMin(600, face.width()));
+
+    /* Delete file, otherwise face.save() will fail */
+    QFile::remove(m_tmpFile);
+    if (! face.save(m_tmpFile, "PNG", 10)) {
+        qCDebug(USER_MANAGER_LOG) << "Saving icon failed";
+        setError(UserDefinedError);
+        emitResult();
+        return;
+    }
+
     emitResult();
 }
